.. _aerospike_operation_helpers.cdt_ctx:

aerospike\_helpers\.cdt_ctx module
------------------------------------------------------

.. note:: Requires server version >= 4.6.0

.. automodule:: aerospike_helpers.cdt_ctx
    :members:
    :undoc-members:
    :show-inheritance: